import{n as e}from"./chunk-Bh1tDfsg.js";import{n as t,t as n}from"./jsx-runtime-BKZ-v_4m.js";import{d as r}from"./useTranslation-l30fIyqu.js";var i=e(t(),1),a=e(r(),1),o={separator:`_separator_1qgmy_7`,section:`_section_1qgmy_11`},s=n(),c=(0,i.forwardRef)(({kind:e,className:t,...n},r)=>(0,s.jsx)(`div`,{"aria-orientation":`horizontal`,role:`separator`,className:(0,a.default)(o.separator,e===`section`&&o.section,t),...n,ref:r}));export{c as t};
//# sourceMappingURL=Separator-BYkx3-r6.js.map