import{t as e}from"./jsx-runtime-BKZ-v_4m.js";import{D as t,K as n}from"./main-CxGi0fIe.js";var r=e(),i=()=>(0,r.jsx)(t,{children:(0,r.jsx)(n,{})});export{i as component};
//# sourceMappingURL=reset-cross-signing-COWPn3-f.js.map