import{s as e}from"./graphql-Dsv3IYEA.js";import{t}from"./jsx-runtime-BKZ-v_4m.js";import{n}from"./not-found-i5RsCZif.js";import{t as r}from"./useTranslation-l30fIyqu.js";import{t as i}from"./error-solid-bRl8FwTZ.js";import{D as a,O as o,a as s,r as c}from"./main-CxGi0fIe.js";import{t as l}from"./ButtonLink-BcHfDxZ3.js";import{t as u}from"./arrow-left-zUhvGJXt.js";var d=t();function f(){let{id:t}=c.useParams(),{data:{userEmailAuthentication:f}}=e(s(t));if(!f)throw n();let{t:p}=r();return(0,d.jsxs)(a,{children:[(0,d.jsx)(o,{Icon:i,invalid:!0,title:p(`frontend.email_in_use.heading`,{email:f.email})}),(0,d.jsx)(l,{Icon:u,kind:`tertiary`,to:`/`,children:p(`action.back`)})]})}export{f as component};
//# sourceMappingURL=emails._id.in-use-Db_QhE5u.js.map