._device-type-icon_10tr1_8{color:var(--cpd-color-icon-secondary);background-color:var(--cpd-color-bg-subtle-secondary);box-sizing:content-box;height:var(--cpd-space-6x);width:var(--cpd-space-6x);padding:var(--cpd-space-2x);border-radius:var(--cpd-space-2x)}._session-card-root_8sc98_8{position:relative}@media screen and (width>=768px){._session-card-root_8sc98_8:has(._action_8sc98_13) ._session-card_8sc98_8 ._card-header_8sc98_13{padding-inline-end:calc(var(--cpd-space-16x) + 10ch)}}@media screen and (width<=767px){._session-card-root_8sc98_8:has(._action_8sc98_13) ._session-card_8sc98_8{padding-block-end:calc(var(--cpd-space-9x) + var(--cpd-space-6x) + var(--cpd-space-6x))}}._session-card_8sc98_8{gap:var(--cpd-space-4x);text-align:start;border-radius:var(--cpd-space-4x);background-color:var(--cpd-color-bg-canvas-default);outline:1px solid var(--cpd-color-border-interactive-secondary);outline-offset:-1px;padding:var(--cpd-space-6x);flex-direction:column;display:flex;box-shadow:0 1.2px 2.4px #00000026}._session-card_8sc98_8._disabled_8sc98_59{outline-color:var(--cpd-color-border-disabled);background-color:var(--cpd-color-bg-canvas-disabled);box-shadow:none}._session-card_8sc98_8._compact_8sc98_65{box-shadow:none;padding:var(--cpd-space-3x)}._session-card_8sc98_8 ._card-header_8sc98_13{gap:var(--cpd-space-4x);align-items:center;display:flex}._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75{flex-direction:column;flex:0 auto;min-width:0;display:flex}._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75._auto_8sc98_83 div:first-child,._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75 ._name_8sc98_84{white-space:nowrap;text-overflow:ellipsis;font:var(--cpd-font-body-md-semibold);letter-spacing:var(--cpd-font-letter-spacing-body-md);color:var(--cpd-color-text-primary);overflow:hidden}._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75._auto_8sc98_83 div:not(:first-child),._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75 ._client_8sc98_94{white-space:nowrap;text-overflow:ellipsis;font:var(--cpd-font-body-sm-regular);letter-spacing:var(--cpd-font-letter-spacing-body-sm);color:var(--cpd-color-text-secondary);overflow:hidden}:is(._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75._auto_8sc98_83 div:not(:first-child),._session-card_8sc98_8 ._card-header_8sc98_13 ._content_8sc98_75 ._client_8sc98_94) img{margin-inline-end:var(--cpd-space-1x)}._session-card_8sc98_8 ._metadata_8sc98_109{gap:var(--cpd-space-4x) var(--cpd-space-10x);flex-wrap:wrap;display:flex}._session-card_8sc98_8 ._metadata_8sc98_109>*{min-width:0}._session-card_8sc98_8 ._metadata_8sc98_109 ._key_8sc98_118{font:var(--cpd-font-body-sm-regular);letter-spacing:var(--cpd-font-letter-spacing-body-sm);color:var(--cpd-color-text-secondary)}._session-card_8sc98_8 ._metadata_8sc98_109 ._value_8sc98_124{font:var(--cpd-font-body-md-regular);letter-spacing:var(--cpd-font-letter-spacing-body-md);color:var(--cpd-color-text-primary);text-overflow:ellipsis;overflow:hidden}a._session-card_8sc98_8:not(._disabled_8sc98_59){transition-property:outline-color,box-shadow;transition-duration:.1s;transition-timing-function:linear}a._session-card_8sc98_8:not(._disabled_8sc98_59):hover,a._session-card_8sc98_8:not(._disabled_8sc98_59):focus-visible{box-shadow:none;outline:2px solid var(--cpd-color-border-interactive-hovered);outline-offset:-2px}a._session-card_8sc98_8:not(._disabled_8sc98_59):focus-visible{outline-color:var(--cpd-color-border-focused)}@media screen and (width>=768px){._session-card-root_8sc98_8 ._action_8sc98_13{padding:var(--cpd-space-6x) var(--cpd-space-6x) var(--cpd-space-2x) var(--cpd-space-2x);position:absolute;inset-block-start:0;inset-inline-end:0}}@media screen and (width<=767px){._session-card-root_8sc98_8 ._action_8sc98_13{padding:var(--cpd-space-6x);flex-direction:column;display:flex;position:absolute;inset-block-end:0;inset-inline:0}}
