import{n as e}from"./chunk-Bh1tDfsg.js";import{n as t}from"./jsx-runtime-BKZ-v_4m.js";var n=e(t(),1),r=n.createContext(void 0),i=n.createContext(void 0);export{r as n,i as t};
//# sourceMappingURL=matchContext-DSkzfCB4.js.map