._empty-state_1lwui_8{gap:var(--cpd-space-2x);padding:var(--cpd-space-4x);background:var(--cpd-color-gray-200);color:var(--cpd-color-text-secondary);font:var(--cpd-font-body-sm-regular);letter-spacing:var(--cpd-font-letter-spacing-body-sm);flex-direction:column;display:flex}._filter_nv8wu_8{align-items:center;gap:var(--cpd-space-2x);font:var(--cpd-font-body-xs-regular);letter-spacing:var(--cpd-font-letter-spacing-body-xs);padding:var(--cpd-space-2x) var(--cpd-space-3x);border-radius:var(--cpd-radius-pill-effect);display:flex}._enabled-filter_nv8wu_18{background:var(--cpd-color-bg-action-primary-rest);color:var(--cpd-color-text-on-solid-primary)}._enabled-filter_nv8wu_18>._close-icon_nv8wu_22{height:var(--cpd-space-4x);width:var(--cpd-space-4x);opacity:.5}._enabled-filter_nv8wu_18:hover{background:var(--cpd-color-bg-action-primary-hovered)}._enabled-filter_nv8wu_18:hover>._close-icon_nv8wu_22{opacity:1}._enabled-filter_nv8wu_18:active{background:var(--cpd-color-bg-action-primary-rest)}._enabled-filter_nv8wu_18:active>._close-icon_nv8wu_22{opacity:1}._disabled-filter_nv8wu_43{color:var(--cpd-color-text-action-primary);background:var(--cpd-color-bg-canvas-default);outline:1px solid var(--cpd-color-border-interactive-secondary)}._disabled-filter_nv8wu_43:hover{background:var(--cpd-color-bg-subtle-secondary)}
