._link_1g96u_8{color:var(--cpd-color-text-primary);font-weight:var(--cpd-font-weight-medium);border-radius:var(--cpd-radius-pill-effect);padding-inline:.25rem;text-decoration:underline;display:inline-block}._link_1g96u_8:hover{background:var(--cpd-color-gray-300)}._link_1g96u_8:active{background:var(--cpd-color-text-primary);color:var(--cpd-color-text-on-solid-primary)}._root_1hqni_8{gap:var(--cpd-space-6x);flex-direction:column;display:flex}._heading_1hqni_14{gap:var(--cpd-space-2x);flex-direction:column;display:flex}._trigger_1hqni_20{text-align:start;justify-content:space-between;align-items:center;gap:var(--cpd-space-2x);width:100%;display:flex}._trigger-title_1hqni_29{cursor:pointer;flex-grow:1}._trigger-icon_1hqni_34{transition:transform .1s ease-out}._root_1hqni_8[data-state=closed] ._trigger-icon_1hqni_34{transform:rotate(180deg)}._description_1hqni_42{color:var(--cpd-color-text-secondary);font:var(--cpd-font-body-md-regular);letter-spacing:var(--cpd-font-letter-spacing-body-md)}._content_1hqni_48{gap:var(--cpd-space-6x);flex-direction:column;display:flex}
