import{t as e}from"./jsx-runtime-BKZ-v_4m.js";import{t}from"./useTranslation-l30fIyqu.js";import{D as n,V as r,p as i}from"./main-CxGi0fIe.js";import{t as a}from"./Link-Dw1UBuD0.js";var o=e();function s(){let{t:e}=t(),{_splat:s}=i.useParams();return(0,o.jsx)(n,{children:(0,o.jsxs)(r,{type:`critical`,title:e(`frontend.session_detail.alert.title`,{deviceId:s}),children:[e(`frontend.session_detail.alert.text`),(0,o.jsx)(a,{to:`/sessions`,children:e(`frontend.session_detail.alert.button`)})]})})}export{s as notFoundComponent};
//# sourceMappingURL=devices._-CexjmjxF.js.map