import{n as e}from"./chunk-Bh1tDfsg.js";import{n as t,t as n}from"./jsx-runtime-BKZ-v_4m.js";import{n as r}from"./link-7TH0lj3S.js";import{d as i}from"./useTranslation-l30fIyqu.js";import{t as a}from"./Button-BIiT28Ux.js";var o=e(t(),1),s=e(i(),1),c={buttonLink:`_button-link_x5txo_8`},l=n(),u=r((0,o.forwardRef)(({children:e,className:t,...n},r)=>{let i=!!n.disabled||!!n[`aria-disabled`]||!1;return(0,l.jsx)(a,{as:`a`,...n,className:(0,s.default)(c.buttonLink,t),disabled:i,ref:r,children:e})}));export{u as t};
//# sourceMappingURL=ButtonLink-BcHfDxZ3.js.map