{#
Copyright 2024, 2025 New Vector Ltd.
Copyright 2024 The Matrix.org Foundation C.I.C.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

{% extends "base.html" %}

{% block content %}
  <header class="page-heading">
    <div class="icon">
      {{ icon.send_solid() }}
    </div>

    <div class="header">
      <h1 class="title">{{ _("mas.recovery.progress.heading") }}</h1>
      <p class="text [&>span]:font-medium">{{ _("mas.recovery.progress.description", email=session.email) }}</p>
    </div>
  </header>

  <div class="flex flex-col gap-6">
    {% if resend_failed_due_to_rate_limit | default(false) %}
      <div class="text-critical font-medium">
        {{ _("mas.errors.rate_limit_exceeded") }}
      </div>
    {% endif %}
    <form class="cpd-form-root" method="POST">
      <input type="hidden" name="csrf" value="{{ csrf_token }}" />

      {{ button.button_outline(text=_("mas.recovery.progress.resend_email"), type="submit") }}
    </form>

    {{ button.link_tertiary(text=_("mas.recovery.progress.change_email"), href="/recover") }}
  </div>
{% endblock content %}
