import{n as e}from"./chunk-Bh1tDfsg.js";import{n as t,t as n}from"./jsx-runtime-BKZ-v_4m.js";import{d as r}from"./useTranslation-l30fIyqu.js";var i={"visual-list":`_visual-list_6zpfn_8`},a=e(r(),1);t();var o=n();function s({className:e,children:t,...n}){return(0,o.jsx)(`ul`,{className:(0,a.default)(i[`visual-list`],e),...n,children:t})}var c={"visual-list-item":`_visual-list-item_1nc1y_8`,"visual-list-item-icon":`_visual-list-item-icon_1nc1y_17`,"visual-list-item-icon-success":`_visual-list-item-icon-success_1nc1y_22`,"visual-list-item-icon-destructive":`_visual-list-item-icon-destructive_1nc1y_26`};function l({className:e,children:t,Icon:n,success:r=!1,destructive:i=!1,...s}){return(0,o.jsxs)(`li`,{className:(0,a.default)(c[`visual-list-item`],e),...s,children:[(0,o.jsx)(n,{className:(0,a.default)(c[`visual-list-item-icon`],{[c[`visual-list-item-icon-success`]]:r,[c[`visual-list-item-icon-destructive`]]:i}),width:`24px`,height:`24px`,"aria-hidden":!0}),t]})}export{s as n,l as t};
//# sourceMappingURL=VisualListItem-BzjEwNBe.js.map