import{n as e}from"./chunk-Bh1tDfsg.js";import{n as t,t as n}from"./jsx-runtime-BKZ-v_4m.js";import{d as r}from"./useTranslation-l30fIyqu.js";import{t as i}from"./UnstyledButton-3FxN8fN6.js";var a={button:`_button_1nw83_8`,"icon-only":`_icon-only_1nw83_53`,"has-icon":`_has-icon_1nw83_60`,destructive:`_destructive_1nw83_110`},o=e(r(),1),s=e(t(),1),c=n(),l=(0,s.forwardRef)(function({as:e,kind:t=`primary`,size:n=`lg`,children:r,className:s,iconOnly:l,Icon:u,destructive:d,disabled:f,...p},m){let[h,g]=t===`destructive`?[`secondary`,!0]:[t,d],_=(0,o.default)(a.button,s,{[a[`has-icon`]]:u,[a[`icon-only`]]:l,[a.destructive]:g}),v=l&&n===`lg`?24:20;return(0,c.jsxs)(i,{...p,as:e||`button`,ref:m,className:_,"data-size":n,"data-kind":h,tabIndex:0,disabled:f,children:[u&&(0,c.jsx)(u,{width:v,height:v,className:a.icon,"aria-hidden":!0}),r]})});export{l as t};
//# sourceMappingURL=Button-BIiT28Ux.js.map