import{t as e}from"./jsx-runtime-BKZ-v_4m.js";import{t}from"./useTranslation-l30fIyqu.js";import{t as n}from"./Button-BIiT28Ux.js";import{t as r}from"./error-solid-bRl8FwTZ.js";import{D as i,O as a,W as o}from"./main-CxGi0fIe.js";var s=e();function c({reset:e}){let{t:c}=t();return(0,s.jsxs)(i,{children:[(0,s.jsx)(a,{Icon:r,title:c(`frontend.reset_cross_signing.failure.heading`),invalid:!0}),(0,s.jsx)(o,{className:`text-center text-secondary`,size:`md`,children:c(`frontend.reset_cross_signing.failure.description`)}),(0,s.jsx)(n,{kind:`tertiary`,size:`lg`,onClick:()=>e(),children:c(`action.back`)})]})}export{c as errorComponent};
//# sourceMappingURL=reset-cross-signing-CHGdUlfR.js.map