{#
Copyright 2024, 2025 New Vector Ltd.
Copyright 2022-2024 The Matrix.org Foundation C.I.C.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

{% extends "base.html" %}

{% block content %}
  <header class="page-heading">
    <div class="icon invalid">
      {{ icon.warning() }}
    </div>

    <div class="header">
      <h1 class="title">
        {{ _("mas.upstream_oauth2.link_mismatch.heading") }}
      </h1>
    </div>
  </header>

  {{ logout.button(text=_("action.sign_out"), csrf_token=csrf_token) }}
{% endblock content %}
